use based::get_pg;
use comrade::defer;
use comrade::service::ServiceManager;
use package::{rebuild_pkgs, reindex_pkg};
use std::process::Command;

pub mod builder;
pub mod git;
pub mod package;

#[tokio::main]
async fn main() {
    env_logger::init();

    sqlx::migrate!().run(get_pg!()).await.unwrap();

    reindex_pkg(&std::path::Path::new("./repositories")).await;

    rebuild_pkgs().await;

    let s = ServiceManager::new();
    let s = s.spawn();
    defer!(move || s.join().unwrap());
}

async fn pacco_push(pkg_path: &str, repo: &str) {
    if let Ok(pacco) = std::env::var("PACCO_URL") {
        log::info!("Pushing package to pacco at {pacco}");
        let upload_url = format!("{}/pkg/{repo}/upload", pacco);

        let token = std::env::var("PACCO_TOKEN").unwrap();

        let output = Command::new("curl")
            .arg("-X")
            .arg("POST")
            .arg("-F")
            .arg(format!("pkg=@{}", pkg_path))
            .arg("-H")
            .arg(format!("Token: {token}"))
            .arg(upload_url)
            .output()
            .unwrap();

        if !output.status.success() {
            log::error!("Failed to push to pacco");
        }
    }
}
